@@ -531,7 +531,6 @@ meta_core_get_menu_accelerator (MetaMenuOp           menu_op,
       name = META_KEYBINDING_TOGGLE_STICKY;
       break;
     case META_MENU_OP_ABOVE:
-    case META_MENU_OP_UNABOVE:
       name = META_KEYBINDING_TOGGLE_ABOVE;
       break;
     case META_MENU_OP_WORKSPACES:
@@ -630,7 +629,7 @@ meta_core_begin_grab_op (Display    *xdisplay,
                          Window      frame_xwindow,
                          MetaGrabOp  op,
                          gboolean    pointer_already_grabbed,
-                         int         event_serial,
+                         gboolean    frame_action,
                          int         button,
                          gulong      modmask,
                          guint32     timestamp,
@@ -648,7 +647,7 @@ meta_core_begin_grab_op (Display    *xdisplay,
   
   return meta_display_begin_grab_op (display, screen, window,
                                      op, pointer_already_grabbed,
-                                     event_serial,
+                                     frame_action,
                                      button, modmask,
                                      timestamp, root_x, root_y);
 }
