@@ -181,6 +181,7 @@ struct _MetaDisplay
   Atom atom_metacity_version;
   Atom atom_net_wm_visible_name;
   Atom atom_net_wm_visible_icon_name;
+  Atom atom_net_wm_user_time_window;
 
   /* This is the actual window from focus events,
    * not the one we last set
@@ -253,7 +254,6 @@ struct _MetaDisplay
   MetaScreen *grab_screen;
   MetaWindow *grab_window;
   Window      grab_xwindow;
-  gulong      grab_start_serial;
   int         grab_button;
   int         grab_anchor_root_x;
   int         grab_anchor_root_y;
@@ -449,7 +449,6 @@ gboolean meta_display_begin_grab_op (MetaDisplay *display,
                                      MetaGrabOp   op,
                                      gboolean     pointer_already_grabbed,
                                      gboolean     frame_action,
-                                     int          event_serial,
                                      int          button,
                                      gulong       modmask,
                                      guint32      timestamp,
